#include <QtWidgets>
#include <QApplication>

#include "application.hpp"

int main(int argc, char* argv[])
{
	RinApplication app(argc, argv);
	app.InitializeUI();

	QWidget window;
	window.resize(800, 600);
	window.setWindowTitle(QApplication::translate("title", "rin: Render Information"));

	QLineEdit* prefixLineEdit = new QLineEdit();
	QPushButton* analyzeButton = new QPushButton(
			QApplication::translate("button", "Add sequence"));
	QPushButton* removeButton = new QPushButton(
			QApplication::translate("button", "Remove sequence"));
	QListView* sequenceList = new QListView();

	RenderAnalyzer* analyzer = new RenderAnalyzer(&window, sequenceList);

	QChartView* frameTimeChartView = new QChartView(analyzer->getFrameTimeChart());
	QChartView* renderTimeChartView = new QChartView(analyzer->getRenderTimeChart());

	//removeButton->setEnabled(false);
	sequenceList->setModel(analyzer);

	QHBoxLayout* buttonsLayout = new QHBoxLayout();
	buttonsLayout->addStretch();
	buttonsLayout->addWidget(analyzeButton);
	buttonsLayout->addWidget(removeButton);
	
	QVBoxLayout* sequenceListLayout = new QVBoxLayout();
	sequenceListLayout->addWidget(sequenceList);
	sequenceListLayout->addLayout(buttonsLayout);

	QHBoxLayout* chartsLayout = new QHBoxLayout();
	chartsLayout->addWidget(frameTimeChartView);
	chartsLayout->addWidget(renderTimeChartView);

	QVBoxLayout* verticalLayout = new QVBoxLayout();
	verticalLayout->addLayout(sequenceListLayout, 0);
	verticalLayout->addLayout(chartsLayout, 4);

	window.setLayout(verticalLayout);
	window.show();

	QObject::connect(analyzeButton, SIGNAL(clicked()), analyzer, SLOT(addRender()));
	QObject::connect(removeButton, SIGNAL(clicked()), analyzer, SLOT(removeSelectedRender()));
	QObject::connect(prefixLineEdit, SIGNAL(textChanged(QString)), analyzer, SLOT(prefixChanged(QString)));
	QObject::connect(analyzer, SIGNAL(renderAdded()), prefixLineEdit, SLOT(clear()));

	return app.exec();
}
